@@ -1,6 +1,8 @@
 from typing import TypedDict
 from .utils import file_ext
 import enum
+import pyodide_http
+pyodide_http.patch_all()
 
 class ExportDataType(str, enum.Enum):
     pandas = "pandas"
@@ -28,20 +30,21 @@ def load_export(export: ExportData):
 
         case ExportDataType.raw:
             # load raw
-            return _load_raw()
+            return _load_raw(export)
 
         case _:
             raise ValueError("Unknown export type")
 
 def _load_pandas(export: ExportData):
     import pandas as pd
-    match file_ext(export["value"]):
+    value = export["value"]
+    match file_ext(value):
         case "csv":
-            return pd.read_csv(export["value"])
+            return pd.read_csv(value)
         case "tsv":
-            return pd.read_csv(export["value"], sep="\t")
+            return pd.read_csv(value, sep="\t")
         case "json":
-            return pd.read_json(export["value"])
+            return pd.read_json(value)
         case _:
             raise ValueError("Unknown pandas file type")
 
